==> apache-camel-quarkus-2.15.0-src.zip: camel-quarkus-2.15.0/extensions/spring-rabbitmq/runtime/src/main/java/org/apache/camel/quarkus/component/rabbitmq/graal/SpringRabbitMQSubstitutions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.rabbitmq.graal;

import com.oracle.svm.core.annotate.Alias;
import com.oracle.svm.core.annotate.RecomputeFieldValue;
import com.oracle.svm.core.annotate.Substitute;
import com.oracle.svm.core.annotate.TargetClass;

final class SpringRabbitMQSubstitutions {
}

/**
 * Force disablement of Micrometer in native mode as Spring metrics is not supported
 */
@TargetClass(className = "org.springframework.amqp.rabbit.listener.AbstractMessageListenerContainer")
final class AbstractMessageListenerContainerSubstitutions {

    @Alias
    @RecomputeFieldValue(kind = RecomputeFieldValue.Kind.Reset)
    private boolean micrometerEnabled;

    @Substitute
    public void setMicrometerEnabled(boolean micrometerEnabled) {
        throw new UnsupportedOperationException("Spring RabbitMQ Micrometer metrics is not supported in native mode");
    }
}

==> apache-camel-quarkus-3.15.4-src.zip: camel-quarkus-3.15.4/extensions/spring-rabbitmq/runtime/src/main/java/org/apache/camel/quarkus/component/rabbitmq/graal/SpringRabbitMQSubstitutions.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.rabbitmq.graal;

import com.oracle.svm.core.annotate.Alias;
import com.oracle.svm.core.annotate.RecomputeFieldValue;
import com.oracle.svm.core.annotate.Substitute;
import com.oracle.svm.core.annotate.TargetClass;

final class SpringRabbitMQSubstitutions {
}

/**
 * Force disablement of Micrometer in native mode as Spring metrics is not supported
 */
@TargetClass(className = "org.springframework.amqp.rabbit.listener.ObservableListenerContainer")
final class AbstractMessageListenerContainerSubstitutions {

    @Alias
    @RecomputeFieldValue(kind = RecomputeFieldValue.Kind.Reset)
    private boolean micrometerEnabled;

    @Substitute
    public void setMicrometerEnabled(boolean micrometerEnabled) {
        throw new UnsupportedOperationException("Spring RabbitMQ Micrometer metrics is not supported in native mode");
    }
}
